@@ -5,11 +5,10 @@ from psychopy import visual, event, core
 globalClock = core.Clock()
 win = visual.Window([800,800])
 #make two wedges (in opposite contrast) and alternate them for flashing
-wedge1 = visual.RadialStim(win, tex='sqrXsqr', rgb=1,size=1,
+wedge1 = visual.RadialStim(win, tex='sqrXsqr', color=1,size=1,
     visibleWedge=[0, 45], radialCycles=4, angularCycles=8, interpolate=True)
-wedge2 = visual.RadialStim(win, tex='sqrXsqr', rgb=-1,size=1,
+wedge2 = visual.RadialStim(win, tex='sqrXsqr', color=-1,size=1,
     visibleWedge=[0, 45], radialCycles=4, angularCycles=8, interpolate=True)
-    
 t=0
 rotationRate = 0.01 #revs per sec
 flashPeriod = 0.1 #seconds for one B-W cycle (ie 1/Hz)
@@ -24,5 +23,4 @@ while t<5:#for 5 secs
     stim.draw()
     win.flip()
     
-win.close()
-print win.fps()
\ No newline at end of file
+win.close()
\ No newline at end of file
