@@ -50,7 +50,8 @@ if platform == 'win32':
           data_files=packageData)
 else:
     setup(app=['psychopy/app/psychopyApp.py'],
-        options=dict(py2app=dict( includes=['Tkinter','FileDialog', 'imp'],
+        options=dict(py2app=dict( includes=['Tkinter','FileDialog', 'imp', 'subprocess', 'shlex'],
+                                  excludes=['PyQt4'],#matplotlib will fetch this if posss and we don't need it
                                   frameworks = ["libavbin.dylib","/usr/lib/libxml2.2.dylib"],
                                   resources=resources,
                                   argv_emulation=True,
